@@ -116,12 +116,12 @@ void KioskGui::slotCheckEtcSkel()
     if (!skelFiles.isEmpty())
     {
         KMessageBox::informationList(this,
-            i18n("<qt>Your system contains KDE configuration settings in the "
+            i18n("<qt>Your system contains TDE configuration settings in the "
                  "skeleton directory <b>%1</b>. These files are copied to the "
-                 "personal KDE settings directory of newly created users.<p>"
+                 "personal TDE settings directory of newly created users.<p>"
                  "This may interfere with the correct operation of user profiles.<p>"
                  "Unless a setting has been locked down, settings that have been copied "
-                 "to the personal KDE settings directory of a user will override "
+                 "to the personal TDE settings directory of a user will override "
                  "a default setting configured in a profile.<p>"
                  "<b>If this is not the intended behavior, please remove the offending "
                  "files from the skeleton folder on all systems that you want to "
